# -*- coding: utf-8 -*-
from distutils.core import setup

packages = \
['terra',
 'terra.msg',
 'terra.msg.auth',
 'terra.msg.distribution',
 'terra.msg.market',
 'terra.msg.oracle',
 'terra.msg.pay',
 'terra.msg.staking',
 'terra.utils']

package_data = \
{'': ['*']}

install_requires = \
['bech32>=1.1,<2.0',
 'bip32utils>=0.3.0,<0.4.0',
 'ecdsa>=0.13.2,<0.14.0',
 'mnemonic>=0.18.0,<0.19.0']

setup_kwargs = {
    'name': 'terra-core',
    'version': '0.1.3',
    'description': 'Python library for Terra Core',
    'long_description': '# Terra-py\n\n[![CircleCI](https://circleci.com/gh/terra-project/terra-py/tree/develop.svg?style=svg&circle-token=5f2dc128a3b81385969b69b77db1ed45d9163b5c)](https://circleci.com/gh/terra-project/terra-py/tree/develop)\n[![codecov](https://codecov.io/gh/terra-project/terra-py/branch/develop/graph/badge.svg?token=mYwZ5wP3oU)](https://codecov.io/gh/terra-project/terra-py)\n\n\nPython library for Terra Core\n\n**NOTE:** This is an early version and interface changes could occure until `v1.0.0`.\n\n## Installation\n\n```\npip3 install terra-core\n```\n\n## Usage\n\n- [Example](#example)\n- [Module terra](#module-terra)\n    - [msg](#module-terramsg)\n        - [auth](#module-terramsgauth)\n        - [distribution](#module-terramsgdistribution)\n        - [market](#module-terramsgmarket)\n        - [oracle](#module-terramsgoracle)\n        - [pay](#module-terramsgpay)\n        - [staking](#module-terramsgstaking)\n    - [utils](#module-terrautils)\n        - [crypto](#module-terrautilscrypto)\n\n### Example\n\n```python\nimport os\n\nfrom terra import Account, msg\n\nacc = Account(os.getenv(\'MNEMONIC\'))\n# or generate a new one\n# acc = Account.generate()\n\ndelegate = msg.staking.MsgDelegate(\n    delegator_address=acc.account_address,\n    validator_address=\'terravaloper1p54hc4yy2ajg67j645dn73w3378j6k05vmx9r2\',\n    amount=msg.Coin(amount=\'10000\', denom=\'uluna\')\n)\n\ntx = msg.Tx(\n    fee=msg.Fee(\'10000\', [msg.Coin(\'2000\', \'uluna\')]),\n    memo=\'Delegating my LUNA tokens\',\n    msg=[delegate],\n)\n\ntx.sign_with(acc)\n\ntx.to_json()\n```\n\n### Module `terra`\n\n```python\nAccount(\n    mnemonic: str,\n    account: int = 0,\n    index: int = 0,\n    sequence: str = "0",\n    account_number: str = "0",\n    chain_id: str = "",\n)\nAccount.generate(\n    account: int = 0,\n    index: int = 0,\n    sequence: str = "0",\n    account_number: str = "0",\n    chain_id: str = "",\n)  # return Account\n```\n\n### Module `terra.msg`\n\n```python\nCoin(\n    amount: str,\n    denom: str,\n)\nCoin().to_json(\n    sort: bool = False,\n)  # return str\n\nFee(\n    gas: str,\n    amount: List[terra.msg.Coin],\n)\nFee().to_json(\n    sort: bool = False,\n)  # return str\n\nInOut(\n    address: str,\n    coins: List[terra.msg.Coin],\n)\nInOut().to_json(\n    sort: bool = False,\n)  # return str\n\nReturnType()\nReturnType.BLOCK\nReturnType.ASYNC\nReturnType.SYNC\n\nTx(\n    fee: terra.msg.Fee,\n    memo: str = "",\n    mode: str = terra.msg.ReturnType.BLOCK,\n    msg: List[terra.utils.JsonSerializable] = [],\n    signatures: List[terra.msg.auth.StdSignMessage] = [],\n)\nTx().sign_with(\n    account: terra.Account,\n)  # return None\nTx().to_json(\n    sort: bool = False,\n)  # return str\n```\n\n### Module `terra.msg.auth`\n\n```python\nStdSignMsg(\n    signature: str,\n    pub_key_value: str,\n    pub_key_type: str = "tendermint/PubKeySecp256k1",\n)\nStdSignMsg().to_json(\n    sort: bool = False,\n)  # return str\n\nStdTx(\n    fee: terra.msg.Fee,\n    memo: str = "",\n    msg: List[terra.utils.JsonSerializable] = [],  # all terra.msg classes inherit from JsonSerializable\n    signatures: List[terra.msg.auth.StdSignMessage] = [],\n)\nStdTx().sign_with(\n    account: terra.Account,\n)  # return None\nStdTx().to_json(\n    sort: bool = False,\n)  # return str\n```\n\n### Module `terra.msg.distribution`\n\n```python\nMsgSetWithdrawAddress(\n    delegator_address: str,\n    withdraw_address: str,\n)\nMsgSetWithdrawAddress().to_json(\n    sort: bool = False,\n)  # return str\n\nMsgWithdrawDelegatorReward(\n    delegator_address: str,\n    validator_address: str,\n)\nMsgWithdrawDelegatorReward().to_json(\n    sort: bool = False,\n)  # return str\n```\n\n### Module `terra.msg.market`\n\n```python\nMsgSwap(\n    trader: str,\n    offer_coin: terra.msg.Coin,\n    ask_denom: str,\n)\nMsgSwap().to_json(\n    sort: bool = False,\n)  # return str\n```\n\n### Module `terra.msg.oracle`\n\n```python\nMsgPricePrevote(\n    price: str,\n    salt: str,\n    denom: str,\n    feeder: str,\n    validator: str\n)\nMsgPricePrevote().to_json(\n    sort: bool = False,\n)  # return str\n\nMsgPriceVote(\n    price: str,\n    salt: str,\n    denom: str,\n    feeder: str,\n    validator: str,\n)\nMsgPriceVote().to_json(\n    sort: bool = False,\n)  # return str\n```\n\n### Module `terra.msg.pay`\n\n```python\nMsgMultiSend(\n    inputs: List[terra.msg.InOut],\n    outputs: List[terra.msg.InOut],\n)\nMsgMultiSend().to_json(\n    sort: bool = False,\n)  # return str\n\nMsgSend(\n    amount: List[terra.msg.Coin],\n    from_address: str,\n    to_address: str\n)\nMsgSend().to_json(\n    sort: bool = False,\n)  # return str\n```\n\n### Module `terra.msg.staking`\n\n```python\nMsgBeginRedelegate(\n    delegator_address: str,\n    validator_src_address: str,\n    validator_dst_address: str,\n    amount: terra.msg.Coin,\n)\nMsgBeginRedelegate().to_json(\n    sort: bool = False,\n)  # return str\n\nMsgDelegate(\n    delegator_address: str,\n    validator_address: str,\n    amount: terra.msg.Coin,\n)\nMsgDelegate().to_json(\n    sort: bool = False,\n)  # return str\n\nMsgUndelegate(\n    delegator_address: str,\n    validator_address: str,\n    amount: terra.msg.Coin,\n)\nMsgUndelegate().to_json(\n    sort: bool = False,\n)  # return str\n```\n\n### Module `terra.utils`\n\n```python\nJsonSerializable()\nJsonSerializable().to_json(\n    sort: bool = False,\n)  # return str\n```\n\n### Module `terra.utils.crypto`\n\n```python\ngenerate_salt()  # return str\n\nsha256_and_sign(\n    payload: str,\n    private_key: str,\n    curve: ecdsa.curves.Curve = ecdsa.SECP256k1,\n    canonize: bool = True,\n)  # return bytes\n\nsha256(\n    payload: str,\n)  # return bytes\n```\n\n## Develop\n\nInstall poetry\n\n```bash\npip install --user poetry\n```\n\nInstall dependencies\n\n```bash\npoetry install\n```\n\nFormat Code\n```bash\npoetry run black .\n```\n\nLinting and code style\n\n```bash\npoetry run flake8 .\n```\n\nStatic type checking\n```bash\npoetry run mypy --ignore-missing-imports .\n```\n\nRun tests\n\n```bash\npoetry run coverage run --source terra -m pytest -v\n```\n',
    'author': 'etienne-napoleone',
    'author_email': 'etienne@terra.money',
    'url': 'https://terra.money',
    'packages': packages,
    'package_data': package_data,
    'install_requires': install_requires,
    'python_requires': '>=3.6,<4.0',
}


setup(**setup_kwargs)
